==> kubernetes-model-apps-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apps/DeploymentConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentConditionBuilder extends io.fabric8.kubernetes.api.model.apps.DeploymentConditionFluentImpl<io.fabric8.kubernetes.api.model.apps.DeploymentConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apps.DeploymentCondition,io.fabric8.kubernetes.api.model.apps.DeploymentConditionBuilder>{
  public DeploymentConditionBuilder() {
    this(false);
  }
  public DeploymentConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentCondition(), validationEnabled);
  }
  public DeploymentConditionBuilder(io.fabric8.kubernetes.api.model.apps.DeploymentConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentConditionBuilder(io.fabric8.kubernetes.api.model.apps.DeploymentConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentCondition(), validationEnabled);
  }
  public DeploymentConditionBuilder(io.fabric8.kubernetes.api.model.apps.DeploymentConditionFluent<?> fluent,io.fabric8.kubernetes.api.model.apps.DeploymentCondition instance) {
    this(fluent, instance, false);
  }
  public DeploymentConditionBuilder(io.fabric8.kubernetes.api.model.apps.DeploymentConditionFluent<?> fluent,io.fabric8.kubernetes.api.model.apps.DeploymentCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DeploymentConditionBuilder(io.fabric8.kubernetes.api.model.apps.DeploymentCondition instance) {
    this(instance,false);
  }
  public DeploymentConditionBuilder(io.fabric8.kubernetes.api.model.apps.DeploymentCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apps.DeploymentConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apps.DeploymentCondition build() {
    DeploymentCondition buildable = new DeploymentCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentConditionBuilder that = (DeploymentConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apps-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/apps/DeploymentConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class DeploymentConditionBuilder extends DeploymentConditionFluentImpl<DeploymentConditionBuilder> implements VisitableBuilder<DeploymentCondition,DeploymentConditionBuilder>{
  public DeploymentConditionBuilder() {
    this(false);
  }
  public DeploymentConditionBuilder(Boolean validationEnabled) {
    this(new DeploymentCondition(), validationEnabled);
  }
  public DeploymentConditionBuilder(DeploymentConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentConditionBuilder(DeploymentConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new DeploymentCondition(), validationEnabled);
  }
  public DeploymentConditionBuilder(DeploymentConditionFluent<?> fluent,DeploymentCondition instance) {
    this(fluent, instance, false);
  }
  public DeploymentConditionBuilder(DeploymentConditionFluent<?> fluent,DeploymentCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DeploymentConditionBuilder(DeploymentCondition instance) {
    this(instance,false);
  }
  public DeploymentConditionBuilder(DeploymentCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  DeploymentConditionFluent<?> fluent;
  Boolean validationEnabled;
  public DeploymentCondition build() {
    DeploymentCondition buildable = new DeploymentCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
